@@ -16,15 +16,13 @@ import (
 	"context"
 	"encoding/json"
 
-	"github.com/devfile/devworkspace-operator/pkg/infrastructure"
-
+	"github.com/eclipse-che/che-operator/pkg/common/chetypes"
+	"github.com/eclipse-che/che-operator/pkg/common/constants"
 	"github.com/eclipse-che/che-operator/pkg/deploy/tls"
-	"github.com/eclipse-che/che-operator/pkg/util"
 
-	"github.com/devfile/devworkspace-operator/pkg/constants"
-	org "github.com/eclipse-che/che-operator/api"
-	v1 "github.com/eclipse-che/che-operator/api/v1"
-	"github.com/eclipse-che/che-operator/api/v2alpha1"
+	dwconstants "github.com/devfile/devworkspace-operator/pkg/constants"
+	"github.com/devfile/devworkspace-operator/pkg/infrastructure"
+	chev2 "github.com/eclipse-che/che-operator/api/v2"
 	"github.com/eclipse-che/che-operator/controllers/che"
 	"github.com/eclipse-che/che-operator/controllers/devworkspace"
 	"github.com/eclipse-che/che-operator/controllers/devworkspace/defaults"
@@ -74,7 +72,7 @@ func (r *CheUserNamespaceReconciler) SetupWithManager(mgr ctrl.Manager) error {
 	r.namespaceCache.client = r.client
 
 	var obj client.Object
-	if util.IsOpenShift4 {
+	if infrastructure.IsOpenShift() {
 		obj = &projectv1.Project{}
 	} else {
 		obj = &corev1.Namespace{}
@@ -85,13 +83,13 @@ func (r *CheUserNamespaceReconciler) SetupWithManager(mgr ctrl.Manager) error {
 		For(obj).
 		Watches(&source.Kind{Type: &corev1.Secret{}}, r.watchRulesForSecrets(ctx)).
 		Watches(&source.Kind{Type: &corev1.ConfigMap{}}, r.watchRulesForConfigMaps(ctx)).
-		Watches(&source.Kind{Type: &v1.CheCluster{}}, r.triggerAllNamespaces())
+		Watches(&source.Kind{Type: &chev2.CheCluster{}}, r.triggerAllNamespaces())
 
 	return bld.Complete(r)
 }
 
 func (r *CheUserNamespaceReconciler) watchRulesForSecrets(ctx context.Context) handler.EventHandler {
-	rules := r.commonRules(ctx, deploy.CheTLSSelfSignedCertificateSecretName)
+	rules := r.commonRules(ctx, constants.DefaultSelfSignedCertificateSecretName)
 	return handler.EnqueueRequestsFromMapFunc(
 		handler.MapFunc(func(obj client.Object) []reconcile.Request {
 			return asReconcileRequestsForNamespaces(obj, rules)
@@ -180,7 +178,7 @@ func (r *CheUserNamespaceReconciler) triggerAllNamespaces() handler.EventHandler
 }
 
 func (r *CheUserNamespaceReconciler) hasCheCluster(ctx context.Context, namespace string) bool {
-	list := v1.CheClusterList{}
+	list := chev2.CheClusterList{}
 	if err := r.client.List(ctx, &list, client.InNamespace(namespace)); err != nil {
 		return false
 	}
@@ -210,9 +208,9 @@ func (r *CheUserNamespaceReconciler) Reconcile(ctx context.Context, req ctrl.Req
 	}
 
 	// let's construct the deployContext to be able to use methods from v1 operator
-	deployContext := &deploy.DeployContext{
-		CheCluster: org.AsV1(checluster),
-		ClusterAPI: deploy.ClusterAPI{
+	deployContext := &chetypes.DeployContext{
+		CheCluster: checluster,
+		ClusterAPI: chetypes.ClusterAPI{
 			Client:           r.client,
 			NonCachingClient: r.client,
 			DiscoveryClient:  nil,
@@ -248,7 +246,7 @@ func (r *CheUserNamespaceReconciler) Reconcile(ctx context.Context, req ctrl.Req
 	return ctrl.Result{}, nil
 }
 
-func findManagingCheCluster(key types.NamespacedName) *v2alpha1.CheCluster {
+func findManagingCheCluster(key types.NamespacedName) *chev2.CheCluster {
 	instances := devworkspace.GetCurrentCheClusterInstances()
 	if len(instances) == 0 {
 		return nil
@@ -272,11 +270,10 @@ func findManagingCheCluster(key types.NamespacedName) *v2alpha1.CheCluster {
 	}
 }
 
-func (r *CheUserNamespaceReconciler) reconcileSelfSignedCert(ctx context.Context, deployContext *deploy.DeployContext, targetNs string, checluster *v2alpha1.CheCluster) error {
+func (r *CheUserNamespaceReconciler) reconcileSelfSignedCert(ctx context.Context, deployContext *chetypes.DeployContext, targetNs string, checluster *chev2.CheCluster) error {
 	if err := deleteLegacyObject("server-cert", &corev1.Secret{}, targetNs, checluster, deployContext); err != nil {
 		return err
 	}
-
 	targetCertName := prefixedName("server-cert")
 
 	delSecret := func() error {
@@ -285,7 +282,7 @@ func (r *CheUserNamespaceReconciler) reconcileSelfSignedCert(ctx context.Context
 	}
 
 	cheCert := &corev1.Secret{}
-	if err := r.client.Get(ctx, client.ObjectKey{Name: deploy.CheTLSSelfSignedCertificateSecretName, Namespace: checluster.Namespace}, cheCert); err != nil {
+	if err := r.client.Get(ctx, client.ObjectKey{Name: constants.DefaultSelfSignedCertificateSecretName, Namespace: checluster.Namespace}, cheCert); err != nil {
 		if !errors.IsNotFound(err) {
 			return err
 		}
@@ -307,12 +304,12 @@ func (r *CheUserNamespaceReconciler) reconcileSelfSignedCert(ctx context.Context
 			Name:      targetCertName,
 			Namespace: targetNs,
 			Labels: defaults.AddStandardLabelsForComponent(checluster, userSettingsComponentLabelValue, map[string]string{
-				constants.DevWorkspaceMountLabel:       "true",
-				constants.DevWorkspaceWatchSecretLabel: "true",
+				dwconstants.DevWorkspaceMountLabel:       "true",
+				dwconstants.DevWorkspaceWatchSecretLabel: "true",
 			}),
 			Annotations: map[string]string{
-				constants.DevWorkspaceMountAsAnnotation:   "file",
-				constants.DevWorkspaceMountPathAnnotation: "/tmp/che/secret/",
+				dwconstants.DevWorkspaceMountAsAnnotation:   "file",
+				dwconstants.DevWorkspaceMountPathAnnotation: "/tmp/che/secret/",
 			},
 		},
 		Data: map[string][]byte{
@@ -326,11 +323,10 @@ func (r *CheUserNamespaceReconciler) reconcileSelfSignedCert(ctx context.Context
 	return err
 }
 
-func (r *CheUserNamespaceReconciler) reconcileTrustedCerts(ctx context.Context, deployContext *deploy.DeployContext, targetNs string, checluster *v2alpha1.CheCluster) error {
+func (r *CheUserNamespaceReconciler) reconcileTrustedCerts(ctx context.Context, deployContext *chetypes.DeployContext, targetNs string, checluster *chev2.CheCluster) error {
 	if err := deleteLegacyObject("trusted-ca-certs", &corev1.ConfigMap{}, targetNs, checluster, deployContext); err != nil {
 		return err
 	}
-
 	targetConfigMapName := prefixedName("trusted-ca-certs")
 
 	delConfigMap := func() error {
@@ -356,12 +352,12 @@ func (r *CheUserNamespaceReconciler) reconcileTrustedCerts(ctx context.Context,
 			Name:      targetConfigMapName,
 			Namespace: targetNs,
 			Labels: defaults.AddStandardLabelsForComponent(checluster, userSettingsComponentLabelValue, map[string]string{
-				constants.DevWorkspaceMountLabel:          "true",
-				constants.DevWorkspaceWatchConfigMapLabel: "true",
+				dwconstants.DevWorkspaceMountLabel:          "true",
+				dwconstants.DevWorkspaceWatchConfigMapLabel: "true",
 			}),
 			Annotations: addToFirst(sourceMap.Annotations, map[string]string{
-				constants.DevWorkspaceMountAsAnnotation:   "file",
-				constants.DevWorkspaceMountPathAnnotation: "/public-certs",
+				dwconstants.DevWorkspaceMountAsAnnotation:   "file",
+				dwconstants.DevWorkspaceMountPathAnnotation: "/public-certs",
 			}),
 		},
 		Data: sourceMap.Data,
@@ -382,11 +378,10 @@ func addToFirst(first map[string]string, second map[string]string) map[string]st
 	return first
 }
 
-func (r *CheUserNamespaceReconciler) reconcileProxySettings(ctx context.Context, targetNs string, checluster *v2alpha1.CheCluster, deployContext *deploy.DeployContext) error {
+func (r *CheUserNamespaceReconciler) reconcileProxySettings(ctx context.Context, targetNs string, checluster *chev2.CheCluster, deployContext *chetypes.DeployContext) error {
 	if err := deleteLegacyObject("proxy-settings", &corev1.ConfigMap{}, targetNs, checluster, deployContext); err != nil {
 		return err
 	}
-
 	proxyConfig, err := che.GetProxyConfiguration(deployContext)
 	if err != nil {
 		return err
@@ -428,11 +423,11 @@ func (r *CheUserNamespaceReconciler) reconcileProxySettings(ctx context.Context,
 	}
 
 	requiredLabels := defaults.AddStandardLabelsForComponent(checluster, userSettingsComponentLabelValue, map[string]string{
-		constants.DevWorkspaceMountLabel:          "true",
-		constants.DevWorkspaceWatchConfigMapLabel: "true",
+		dwconstants.DevWorkspaceMountLabel:          "true",
+		dwconstants.DevWorkspaceWatchConfigMapLabel: "true",
 	})
 	requiredAnnos := map[string]string{
-		constants.DevWorkspaceMountAsAnnotation: "env",
+		dwconstants.DevWorkspaceMountAsAnnotation: "env",
 	}
 
 	cfg = &corev1.ConfigMap{
@@ -453,25 +448,23 @@ func (r *CheUserNamespaceReconciler) reconcileProxySettings(ctx context.Context,
 	return err
 }
 
-func (r *CheUserNamespaceReconciler) reconcileGitTlsCertificate(ctx context.Context, targetNs string, checluster *v2alpha1.CheCluster, deployContext *deploy.DeployContext) error {
+func (r *CheUserNamespaceReconciler) reconcileGitTlsCertificate(ctx context.Context, targetNs string, checluster *chev2.CheCluster, deployContext *chetypes.DeployContext) error {
 	if err := deleteLegacyObject("git-tls-creds", &corev1.ConfigMap{}, targetNs, checluster, deployContext); err != nil {
 		return err
 	}
-
 	targetName := prefixedName("git-tls-creds")
 	delConfigMap := func() error {
 		_, err := deploy.Delete(deployContext, client.ObjectKey{Name: targetName, Namespace: targetNs}, &corev1.ConfigMap{})
 		return err
 	}
 
-	clusterv1 := org.AsV1(checluster)
-	if !clusterv1.Spec.Server.GitSelfSignedCert {
+	if checluster.Spec.DevEnvironments.TrustedCerts == nil || checluster.Spec.DevEnvironments.TrustedCerts.GitTrustedCertsConfigMapName == "" {
 		return delConfigMap()
 	}
 
 	gitCert := &corev1.ConfigMap{}
 
-	if err := deployContext.ClusterAPI.Client.Get(ctx, client.ObjectKey{Name: deploy.GitSelfSignedCertsConfigMapName, Namespace: checluster.Namespace}, gitCert); err != nil {
+	if err := deployContext.ClusterAPI.Client.Get(ctx, client.ObjectKey{Name: checluster.Spec.DevEnvironments.TrustedCerts.GitTrustedCertsConfigMapName, Namespace: checluster.Namespace}, gitCert); err != nil {
 		if !errors.IsNotFound(err) {
 			return err
 		}
@@ -487,9 +480,9 @@ func (r *CheUserNamespaceReconciler) reconcileGitTlsCertificate(ctx context.Cont
 			Name:      targetName,
 			Namespace: targetNs,
 			Labels: defaults.AddStandardLabelsForComponent(checluster, userSettingsComponentLabelValue, map[string]string{
-				constants.DevWorkspaceGitTLSLabel:         "true",
-				constants.DevWorkspaceMountLabel:          "true",
-				constants.DevWorkspaceWatchConfigMapLabel: "true",
+				dwconstants.DevWorkspaceGitTLSLabel:         "true",
+				dwconstants.DevWorkspaceMountLabel:          "true",
+				dwconstants.DevWorkspaceWatchConfigMapLabel: "true",
 			}),
 		},
 		Data: map[string]string{
@@ -502,7 +495,7 @@ func (r *CheUserNamespaceReconciler) reconcileGitTlsCertificate(ctx context.Cont
 	return err
 }
 
-func (r *CheUserNamespaceReconciler) reconcileNodeSelectorAndTolerations(ctx context.Context, targetNs string, checluster *v2alpha1.CheCluster, deployContext *deploy.DeployContext) error {
+func (r *CheUserNamespaceReconciler) reconcileNodeSelectorAndTolerations(ctx context.Context, targetNs string, checluster *chev2.CheCluster, deployContext *chetypes.DeployContext) error {
 	var ns client.Object
 
 	if infrastructure.IsOpenShift() {
@@ -518,8 +511,8 @@ func (r *CheUserNamespaceReconciler) reconcileNodeSelectorAndTolerations(ctx con
 	nodeSelector := ""
 	tolerations := ""
 
-	if len(checluster.Spec.Workspaces.PodNodeSelector) != 0 {
-		serialized, err := json.Marshal(checluster.Spec.Workspaces.PodNodeSelector)
+	if len(checluster.Spec.DevEnvironments.NodeSelector) != 0 {
+		serialized, err := json.Marshal(checluster.Spec.DevEnvironments.NodeSelector)
 		if err != nil {
 			return err
 		}
@@ -527,8 +520,8 @@ func (r *CheUserNamespaceReconciler) reconcileNodeSelectorAndTolerations(ctx con
 		nodeSelector = string(serialized)
 	}
 
-	if len(checluster.Spec.Workspaces.PodTolerations) != 0 {
-		serialized, err := json.Marshal(checluster.Spec.Workspaces.PodTolerations)
+	if len(checluster.Spec.DevEnvironments.Tolerations) != 0 {
+		serialized, err := json.Marshal(checluster.Spec.DevEnvironments.Tolerations)
 		if err != nil {
 			return err
 		}
@@ -564,7 +557,7 @@ func prefixedName(name string) string {
 
 // Deletes object with a legacy name to avoid mounting several ones under the same path
 // See https://github.com/eclipse/che/issues/21385
-func deleteLegacyObject(name string, objectMeta client.Object, targetNs string, checluster *v2alpha1.CheCluster, deployContext *deploy.DeployContext) error {
+func deleteLegacyObject(name string, objectMeta client.Object, targetNs string, checluster *chev2.CheCluster, deployContext *chetypes.DeployContext) error {
 	legacyPrefixedName := checluster.Name + "-" + checluster.Namespace + "-" + name
 	key := client.ObjectKey{Name: legacyPrefixedName, Namespace: targetNs}
 
