@@ -12,12 +12,14 @@
 package usernamespace
 
 import (
-	"github.com/eclipse-che/che-operator/pkg/deploy"
+	"github.com/devfile/devworkspace-operator/pkg/infrastructure"
+	defaults "github.com/eclipse-che/che-operator/pkg/common/operator-defaults"
+	"github.com/eclipse-che/che-operator/pkg/common/test"
 )
 
 func init() {
-	err := deploy.InitTestDefaultsFromDeployment("../../config/manager/manager.yaml")
-	if err != nil {
-		panic(err)
-	}
+	test.EnableTestMode()
+
+	infrastructure.InitializeForTesting(infrastructure.OpenShiftv4)
+	defaults.Initialize("../../config/manager/manager.yaml")
 }
