@@ -19,9 +19,15 @@ import (
 
 	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/selection"
+	"k8s.io/utils/pointer"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 
-	"github.com/eclipse-che/che-operator/pkg/util"
+	"github.com/devfile/devworkspace-operator/pkg/infrastructure"
+	chev2 "github.com/eclipse-che/che-operator/api/v2"
+	"github.com/eclipse-che/che-operator/pkg/common/chetypes"
+	"github.com/eclipse-che/che-operator/pkg/common/constants"
+	"github.com/eclipse-che/che-operator/pkg/common/test"
+	"github.com/eclipse-che/che-operator/pkg/common/utils"
 	"github.com/google/go-cmp/cmp"
 	"github.com/google/go-cmp/cmp/cmpopts"
 	"github.com/sirupsen/logrus"
@@ -45,7 +51,7 @@ var DefaultDeploymentDiffOpts = cmp.Options{
 }
 
 func SyncDeploymentSpecToCluster(
-	deployContext *DeployContext,
+	deployContext *chetypes.DeployContext,
 	deploymentSpec *appsv1.Deployment,
 	deploymentDiffOpts cmp.Options) (bool, error) {
 
@@ -72,7 +78,7 @@ func SyncDeploymentSpecToCluster(
 	}
 
 	// always return true for tests
-	if util.IsTestMode() {
+	if test.IsTestMode() {
 		return true, nil
 	}
 
@@ -90,15 +96,95 @@ func SyncDeploymentSpecToCluster(
 	return provisioned, nil
 }
 
+// CustomizeDeployment customize deployment
+func CustomizeDeployment(deployment *appsv1.Deployment, customDeployment *chev2.Deployment, useCustomSecurityContext bool) error {
+	if customDeployment == nil || len(customDeployment.Containers) == 0 {
+		return nil
+	}
+
+	for index, _ := range deployment.Spec.Template.Spec.Containers {
+		container := &deployment.Spec.Template.Spec.Containers[index]
+
+		customContainer := &customDeployment.Containers[0]
+		if len(deployment.Spec.Template.Spec.Containers) != 1 {
+			customContainer = getContainerByName(container.Name, customDeployment.Containers)
+			if customContainer == nil {
+				continue
+			}
+		}
+
+		container.Image = utils.GetValue(customContainer.Image, container.Image)
+
+		if customContainer.ImagePullPolicy != "" {
+			container.ImagePullPolicy = customContainer.ImagePullPolicy
+		} else if container.ImagePullPolicy == "" {
+			container.ImagePullPolicy = corev1.PullPolicy(utils.GetPullPolicyFromDockerImage(container.Image))
+		}
+
+		if customContainer.Resources != nil {
+			if customContainer.Resources.Requests != nil {
+				if !customContainer.Resources.Requests.Memory.IsZero() {
+					container.Resources.Requests[corev1.ResourceMemory] = customContainer.Resources.Requests.Memory
+				}
+				if !customContainer.Resources.Requests.Cpu.IsZero() {
+					container.Resources.Requests[corev1.ResourceCPU] = customContainer.Resources.Requests.Cpu
+				}
+			}
+
+			if customContainer.Resources.Limits != nil {
+				if !customContainer.Resources.Limits.Memory.IsZero() {
+					container.Resources.Limits[corev1.ResourceMemory] = customContainer.Resources.Limits.Memory
+				}
+				if !customContainer.Resources.Limits.Cpu.IsZero() {
+					container.Resources.Limits[corev1.ResourceCPU] = customContainer.Resources.Limits.Cpu
+				}
+			}
+		}
+	}
+
+	if !infrastructure.IsOpenShift() {
+		if useCustomSecurityContext {
+			if customDeployment.SecurityContext != nil {
+				if customDeployment.SecurityContext.FsGroup != nil {
+					deployment.Spec.Template.Spec.SecurityContext.FSGroup = pointer.Int64Ptr(*customDeployment.SecurityContext.FsGroup)
+				}
+
+				if customDeployment.SecurityContext.RunAsUser != nil {
+					deployment.Spec.Template.Spec.SecurityContext.RunAsUser = pointer.Int64Ptr(*customDeployment.SecurityContext.RunAsUser)
+				}
+			}
+		}
+	}
+
+	return nil
+}
+
+func getOrDefaultQuantity(value resource.Quantity, defaultValue resource.Quantity) resource.Quantity {
+	if !value.IsZero() {
+		return value
+	}
+	return defaultValue
+}
+
+func getContainerByName(name string, containers []chev2.Container) *chev2.Container {
+	for _, c := range containers {
+		if c.Name == name {
+			return &c
+		}
+	}
+
+	return nil
+}
+
 // MountSecrets mounts secrets into a container as a file or as environment variable.
 // Secrets are selected by the following labels:
 // - app.kubernetes.io/part-of=che.eclipse.org
 // - app.kubernetes.io/component=<DEPLOYMENT-NAME>-secret
-func MountSecrets(specDeployment *appsv1.Deployment, deployContext *DeployContext) error {
+func MountSecrets(specDeployment *appsv1.Deployment, deployContext *chetypes.DeployContext) error {
 	secrets := &corev1.SecretList{}
 
-	kubernetesPartOfLabelSelectorRequirement, _ := labels.NewRequirement(KubernetesPartOfLabelKey, selection.Equals, []string{CheEclipseOrg})
-	kubernetesComponentLabelSelectorRequirement, _ := labels.NewRequirement(KubernetesComponentLabelKey, selection.Equals, []string{specDeployment.Name + "-secret"})
+	kubernetesPartOfLabelSelectorRequirement, _ := labels.NewRequirement(constants.KubernetesPartOfLabelKey, selection.Equals, []string{constants.CheEclipseOrg})
+	kubernetesComponentLabelSelectorRequirement, _ := labels.NewRequirement(constants.KubernetesComponentLabelKey, selection.Equals, []string{specDeployment.Name + "-secret"})
 
 	listOptions := &client.ListOptions{
 		LabelSelector: labels.NewSelector().Add(*kubernetesPartOfLabelSelectorRequirement).Add(*kubernetesComponentLabelSelectorRequirement),
@@ -114,7 +200,7 @@ func MountSecrets(specDeployment *appsv1.Deployment, deployContext *DeployContex
 
 	container := &specDeployment.Spec.Template.Spec.Containers[0]
 	for _, secretObj := range secrets.Items {
-		switch secretObj.Annotations[CheEclipseOrgMountAs] {
+		switch secretObj.Annotations[constants.CheEclipseOrgMountAs] {
 		case "file":
 			voluseSource := corev1.VolumeSource{
 				Secret: &corev1.SecretVolumeSource{
@@ -129,7 +215,7 @@ func MountSecrets(specDeployment *appsv1.Deployment, deployContext *DeployContex
 
 			volumeMount := corev1.VolumeMount{
 				Name:      secretObj.Name,
-				MountPath: secretObj.Annotations[CheEclipseOrgMountPath],
+				MountPath: secretObj.Annotations[constants.CheEclipseOrgMountPath],
 			}
 
 			specDeployment.Spec.Template.Spec.Volumes = append(specDeployment.Spec.Template.Spec.Volumes, volume)
@@ -157,15 +243,15 @@ func MountSecrets(specDeployment *appsv1.Deployment, deployContext *DeployContex
 				var envName string
 
 				// check if evn name defined explicitly
-				envNameAnnotation := CheEclipseOrg + "/" + key + "_env-name"
+				envNameAnnotation := constants.CheEclipseOrg + "/" + key + "_env-name"
 				envName, envNameExists := secretObj.Annotations[envNameAnnotation]
 				if !envNameExists {
 					// check if there is only one env name to mount
-					envName, envNameExists = secretObj.Annotations[CheEclipseOrgEnvName]
+					envName, envNameExists = secretObj.Annotations[constants.CheEclipseOrgEnvName]
 					if len(secret.Data) > 1 {
 						return fmt.Errorf("There are more than one environment variable to mount. Use annotation '%s' to specify a name", envNameAnnotation)
 					} else if !envNameExists {
-						return fmt.Errorf("Environment name to mount secret key not found. Use annotation '%s' to specify a name", CheEclipseOrgEnvName)
+						return fmt.Errorf("Environment name to mount secret key not found. Use annotation '%s' to specify a name", constants.CheEclipseOrgEnvName)
 					}
 				}
 
@@ -192,11 +278,11 @@ func MountSecrets(specDeployment *appsv1.Deployment, deployContext *DeployContex
 // Configmaps are selected by the following labels:
 // - app.kubernetes.io/part-of=che.eclipse.org
 // - app.kubernetes.io/component=<DEPLOYMENT-NAME>-configmap
-func MountConfigMaps(specDeployment *appsv1.Deployment, deployContext *DeployContext) error {
+func MountConfigMaps(specDeployment *appsv1.Deployment, deployContext *chetypes.DeployContext) error {
 	configmaps := &corev1.ConfigMapList{}
 
-	kubernetesPartOfLabelSelectorRequirement, _ := labels.NewRequirement(KubernetesPartOfLabelKey, selection.Equals, []string{CheEclipseOrg})
-	kubernetesComponentLabelSelectorRequirement, _ := labels.NewRequirement(KubernetesComponentLabelKey, selection.Equals, []string{specDeployment.Name + "-configmap"})
+	kubernetesPartOfLabelSelectorRequirement, _ := labels.NewRequirement(constants.KubernetesPartOfLabelKey, selection.Equals, []string{constants.CheEclipseOrg})
+	kubernetesComponentLabelSelectorRequirement, _ := labels.NewRequirement(constants.KubernetesComponentLabelKey, selection.Equals, []string{specDeployment.Name + "-configmap"})
 
 	listOptions := &client.ListOptions{
 		LabelSelector: labels.NewSelector().Add(*kubernetesPartOfLabelSelectorRequirement).Add(*kubernetesComponentLabelSelectorRequirement),
@@ -212,7 +298,7 @@ func MountConfigMaps(specDeployment *appsv1.Deployment, deployContext *DeployCon
 
 	container := &specDeployment.Spec.Template.Spec.Containers[0]
 	for _, configMapObj := range configmaps.Items {
-		switch configMapObj.Annotations[CheEclipseOrgMountAs] {
+		switch configMapObj.Annotations[constants.CheEclipseOrgMountAs] {
 		case "file":
 			voluseSource := corev1.VolumeSource{
 				ConfigMap: &corev1.ConfigMapVolumeSource{
@@ -229,7 +315,7 @@ func MountConfigMaps(specDeployment *appsv1.Deployment, deployContext *DeployCon
 
 			volumeMount := corev1.VolumeMount{
 				Name:      configMapObj.Name,
-				MountPath: configMapObj.Annotations[CheEclipseOrgMountPath],
+				MountPath: configMapObj.Annotations[constants.CheEclipseOrgMountPath],
 			}
 
 			specDeployment.Spec.Template.Spec.Volumes = append(specDeployment.Spec.Template.Spec.Volumes, volume)
@@ -257,15 +343,15 @@ func MountConfigMaps(specDeployment *appsv1.Deployment, deployContext *DeployCon
 				var envName string
 
 				// check if evn name defined explicitly
-				envNameAnnotation := CheEclipseOrg + "/" + key + "_env-name"
+				envNameAnnotation := constants.CheEclipseOrg + "/" + key + "_env-name"
 				envName, envNameExists := configMapObj.Annotations[envNameAnnotation]
 				if !envNameExists {
 					// check if there is only one env name to mount
-					envName, envNameExists = configMapObj.Annotations[CheEclipseOrgEnvName]
+					envName, envNameExists = configMapObj.Annotations[constants.CheEclipseOrgEnvName]
 					if len(configmap.Data) > 1 {
 						return fmt.Errorf("There are more than one environment variable to mount. Use annotation '%s' to specify a name", envNameAnnotation)
 					} else if !envNameExists {
-						return fmt.Errorf("Environment name to mount configmap key not found. Use annotation '%s' to specify a name", CheEclipseOrgEnvName)
+						return fmt.Errorf("Environment name to mount configmap key not found. Use annotation '%s' to specify a name", constants.CheEclipseOrgEnvName)
 					}
 				}
 
