@@ -18,8 +18,11 @@ import (
 
 	admissionregistrationv1 "k8s.io/api/admissionregistration/v1"
 
+	"github.com/devfile/devworkspace-operator/pkg/infrastructure"
+	"github.com/eclipse-che/che-operator/pkg/common/chetypes"
+	"github.com/eclipse-che/che-operator/pkg/common/constants"
+	"github.com/eclipse-che/che-operator/pkg/common/test"
 	"github.com/eclipse-che/che-operator/pkg/deploy"
-	"github.com/eclipse-che/che-operator/pkg/util"
 	"github.com/sirupsen/logrus"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/types"
@@ -50,8 +53,8 @@ func NewDevWorkspaceReconciler() *DevWorkspaceReconciler {
 	return &DevWorkspaceReconciler{}
 }
 
-func (d *DevWorkspaceReconciler) Reconcile(ctx *deploy.DeployContext) (reconcile.Result, bool, error) {
-	if util.IsOpenShift {
+func (d *DevWorkspaceReconciler) Reconcile(ctx *chetypes.DeployContext) (reconcile.Result, bool, error) {
+	if infrastructure.IsOpenShift() {
 		// Do nothing if explicitly declared not to manage Dev Workspace resources
 		isNoOptDWO, err := isNoOptDWO()
 		if isNoOptDWO {
@@ -81,7 +84,7 @@ func (d *DevWorkspaceReconciler) Reconcile(ctx *deploy.DeployContext) (reconcile
 			return reconcile.Result{Requeue: true}, false, err
 		}
 
-		namespaceOwnershipAnnotation := namespace.GetAnnotations()[deploy.CheEclipseOrgNamespace]
+		namespaceOwnershipAnnotation := namespace.GetAnnotations()[constants.CheEclipseOrgNamespace]
 		if namespaceOwnershipAnnotation == "" {
 			// don't manage DWO if namespace is created by someone else not but not Che Operator
 			return reconcile.Result{}, true, nil
@@ -102,7 +105,7 @@ func (d *DevWorkspaceReconciler) Reconcile(ctx *deploy.DeployContext) (reconcile
 		}
 	}
 
-	if !util.IsTestMode() {
+	if !test.IsTestMode() {
 		if !devWorkspaceWebHookExistedBeforeSync {
 			// we need to restart Che Operator to switch devworkspace controller mode
 			restartCheOperator()
@@ -112,6 +115,6 @@ func (d *DevWorkspaceReconciler) Reconcile(ctx *deploy.DeployContext) (reconcile
 	return reconcile.Result{}, true, nil
 }
 
-func (d *DevWorkspaceReconciler) Finalize(ctx *deploy.DeployContext) bool {
+func (d *DevWorkspaceReconciler) Finalize(ctx *chetypes.DeployContext) bool {
 	return true
 }
