@@ -15,15 +15,17 @@ import (
 	"context"
 	"os"
 
-	orgv1 "github.com/eclipse-che/che-operator/api/v1"
-	"github.com/eclipse-che/che-operator/pkg/util"
-
+	defaults "github.com/eclipse-che/che-operator/pkg/common/operator-defaults"
 	"k8s.io/apimachinery/pkg/types"
 
 	k8sErrors "k8s.io/apimachinery/pkg/api/errors"
 
 	"testing"
 
+	"github.com/devfile/devworkspace-operator/pkg/infrastructure"
+	chev2 "github.com/eclipse-che/che-operator/api/v2"
+	"github.com/eclipse-che/che-operator/pkg/common/constants"
+	"github.com/eclipse-che/che-operator/pkg/common/test"
 	"github.com/eclipse-che/che-operator/pkg/deploy"
 	"github.com/stretchr/testify/assert"
 	appsv1 "k8s.io/api/apps/v1"
@@ -34,74 +36,54 @@ import (
 )
 
 func TestReconcileDevWorkspace(t *testing.T) {
+	cheOperatorDeployment := &appsv1.Deployment{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      defaults.GetCheFlavor() + "-operator",
+			Namespace: "eclipse-che",
+		},
+	}
+
 	type testCase struct {
-		name         string
-		IsOpenShift  bool
-		IsOpenShift4 bool
-		cheCluster   *orgv1.CheCluster
+		name           string
+		infrastructure infrastructure.Type
+		cheCluster     *chev2.CheCluster
 	}
 
 	testCases := []testCase{
 		{
 			name: "Reconcile DevWorkspace on OpenShift",
-			cheCluster: &orgv1.CheCluster{
+			cheCluster: &chev2.CheCluster{
 				ObjectMeta: metav1.ObjectMeta{
 					Namespace: "eclipse-che",
-					Name:      "eclipse-che",
-				},
-				Spec: orgv1.CheClusterSpec{
-					DevWorkspace: orgv1.CheClusterSpecDevWorkspace{
-						Enable: true,
-					},
 				},
 			},
-			IsOpenShift:  true,
-			IsOpenShift4: true,
+			infrastructure: infrastructure.OpenShiftv4,
 		},
 		{
 			name: "Reconcile DevWorkspace on K8S",
-			cheCluster: &orgv1.CheCluster{
+			cheCluster: &chev2.CheCluster{
 				ObjectMeta: metav1.ObjectMeta{
 					Namespace: "eclipse-che",
 				},
-				Spec: orgv1.CheClusterSpec{
-					DevWorkspace: orgv1.CheClusterSpecDevWorkspace{
-						Enable: true,
+				Spec: chev2.CheClusterSpec{
+					Components: chev2.CheClusterComponents{
+						CheServer: chev2.CheServer{
+							ExtraProperties: map[string]string{"CHE_INFRA_KUBERNETES_ENABLE__UNSUPPORTED__K8S": "true"},
+						},
 					},
-					Server: orgv1.CheClusterSpecServer{
-						CustomCheProperties: map[string]string{"CHE_INFRA_KUBERNETES_ENABLE__UNSUPPORTED__K8S": "true"},
-					},
-					K8s: orgv1.CheClusterSpecK8SOnly{
-						IngressDomain: "che.domain",
+					Networking: chev2.CheClusterSpecNetworking{
+						Domain: "che.domain",
 					},
 				},
 			},
-			IsOpenShift:  false,
-			IsOpenShift4: false,
+			infrastructure: infrastructure.Kubernetes,
 		},
 	}
 
 	for _, testCase := range testCases {
 		t.Run(testCase.name, func(t *testing.T) {
-			cheOperatorDeployment := &appsv1.Deployment{
-				ObjectMeta: metav1.ObjectMeta{
-					Name:      deploy.DefaultCheFlavor(testCase.cheCluster) + "-operator",
-					Namespace: "eclipse-che",
-				},
-			}
-
-			deployContext := deploy.GetTestDeployContext(testCase.cheCluster, []runtime.Object{cheOperatorDeployment})
-
-			util.IsOpenShift = testCase.IsOpenShift
-			util.IsOpenShift4 = testCase.IsOpenShift4
-
-			// reread templates (workaround after setting IsOpenShift value)
-			DevWorkspaceTemplates = DevWorkspaceTemplatesPath()
-			DevWorkspaceIssuerFile = DevWorkspaceTemplates + "/devworkspace-controller-selfsigned-issuer.Issuer.yaml"
-			DevWorkspaceCertificateFile = DevWorkspaceTemplates + "/devworkspace-controller-serving-cert.Certificate.yaml"
-
-			err := os.Setenv("ALLOW_DEVWORKSPACE_ENGINE", "true")
-			assert.NoError(t, err)
+			deployContext := test.GetDeployContext(testCase.cheCluster, []runtime.Object{cheOperatorDeployment})
+			infrastructure.InitializeForTesting(testCase.infrastructure)
 
 			devWorkspaceReconciler := NewDevWorkspaceReconciler()
 			_, done, err := devWorkspaceReconciler.Reconcile(deployContext)
@@ -112,20 +94,9 @@ func TestReconcileDevWorkspace(t *testing.T) {
 }
 
 func TestShouldReconcileDevWorkspaceIfDevWorkspaceDeploymentExists(t *testing.T) {
-	cheCluster := &orgv1.CheCluster{
-		ObjectMeta: metav1.ObjectMeta{
-			Namespace: "eclipse-che",
-			Name:      "eclipse-che",
-		},
-		Spec: orgv1.CheClusterSpec{
-			DevWorkspace: orgv1.CheClusterSpecDevWorkspace{
-				Enable: true,
-			},
-		},
-	}
 	cheOperatorDeployment := &appsv1.Deployment{
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      deploy.DefaultCheFlavor(cheCluster) + "-operator",
+			Name:      defaults.GetCheFlavor() + "-operator",
 			Namespace: "eclipse-che",
 		},
 	}
@@ -138,18 +109,14 @@ func TestShouldReconcileDevWorkspaceIfDevWorkspaceDeploymentExists(t *testing.T)
 			Name:      DevWorkspaceDeploymentName,
 			Namespace: DevWorkspaceNamespace,
 			Labels: map[string]string{
-				deploy.KubernetesPartOfLabelKey: deploy.DevWorkspaceOperator,
-				deploy.KubernetesNameLabelKey:   deploy.DevWorkspaceController,
+				constants.KubernetesPartOfLabelKey: constants.DevWorkspaceOperator,
+				constants.KubernetesNameLabelKey:   constants.DevWorkspaceController,
 			},
 		},
 	}
 
-	deployContext := deploy.GetTestDeployContext(cheCluster, []runtime.Object{cheOperatorDeployment, devworkspaceDeployment})
-
-	util.IsOpenShift = true
-	util.IsOpenShift4 = true
-	err := os.Setenv("ALLOW_DEVWORKSPACE_ENGINE", "false")
-	assert.NoError(t, err)
+	deployContext := test.GetDeployContext(nil, []runtime.Object{devworkspaceDeployment, cheOperatorDeployment})
+	infrastructure.InitializeForTesting(infrastructure.OpenShiftv4)
 
 	devWorkspaceReconciler := NewDevWorkspaceReconciler()
 	_, done, err := devWorkspaceReconciler.Reconcile(deployContext)
@@ -159,20 +126,9 @@ func TestShouldReconcileDevWorkspaceIfDevWorkspaceDeploymentExists(t *testing.T)
 }
 
 func TestShouldNotReconcileDevWorkspaceIfDevWorkspaceDeploymentManagedByOLM(t *testing.T) {
-	cheCluster := &orgv1.CheCluster{
-		ObjectMeta: metav1.ObjectMeta{
-			Namespace: "eclipse-che",
-			Name:      "eclipse-che",
-		},
-		Spec: orgv1.CheClusterSpec{
-			DevWorkspace: orgv1.CheClusterSpecDevWorkspace{
-				Enable: true,
-			},
-		},
-	}
 	cheOperatorDeployment := &appsv1.Deployment{
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      deploy.DefaultCheFlavor(cheCluster) + "-operator",
+			Name:      defaults.GetCheFlavor() + "-operator",
 			Namespace: "eclipse-che",
 		},
 	}
@@ -185,89 +141,55 @@ func TestShouldNotReconcileDevWorkspaceIfDevWorkspaceDeploymentManagedByOLM(t *t
 			Name:      DevWorkspaceDeploymentName,
 			Namespace: DevWorkspaceNamespace,
 			Labels: map[string]string{
-				deploy.KubernetesPartOfLabelKey: deploy.DevWorkspaceOperator,
-				deploy.KubernetesNameLabelKey:   deploy.DevWorkspaceController,
+				constants.KubernetesPartOfLabelKey: constants.DevWorkspaceOperator,
+				constants.KubernetesNameLabelKey:   constants.DevWorkspaceController,
 			},
 			OwnerReferences: []metav1.OwnerReference{{}},
 		},
 	}
 
-	deployContext := deploy.GetTestDeployContext(cheCluster, []runtime.Object{cheOperatorDeployment, devworkspaceDeployment})
-
-	util.IsOpenShift = true
-	util.IsOpenShift4 = true
-	err := os.Setenv("ALLOW_DEVWORKSPACE_ENGINE", "true")
-	assert.NoError(t, err)
+	deployContext := test.GetDeployContext(nil, []runtime.Object{cheOperatorDeployment, devworkspaceDeployment})
+	infrastructure.InitializeForTesting(infrastructure.OpenShiftv4)
 
 	devWorkspaceReconciler := NewDevWorkspaceReconciler()
 	_, done, err := devWorkspaceReconciler.Reconcile(deployContext)
 
-	assert.NoError(t, err)
 	assert.True(t, done)
 
 	// verify that DWO is not provisioned
-	namespace := &corev1.Namespace{}
-	err = deployContext.ClusterAPI.NonCachingClient.Get(context.TODO(), types.NamespacedName{Name: DevWorkspaceNamespace}, namespace)
+	err = deployContext.ClusterAPI.NonCachingClient.Get(context.TODO(), types.NamespacedName{Name: DevWorkspaceNamespace}, &corev1.Namespace{})
 	assert.True(t, k8sErrors.IsNotFound(err))
 }
 
 func TestShouldNotReconcileDevWorkspaceIfNoOptExists(t *testing.T) {
-	err := os.Setenv("NO_OPT_DWO", "true")
-	assert.NoError(t, err)
+	os.Setenv("NO_OPT_DWO", "true")
 
-	cheCluster := &orgv1.CheCluster{
-		ObjectMeta: metav1.ObjectMeta{
-			Namespace: "eclipse-che",
-			Name:      "eclipse-che",
-		},
-		Spec: orgv1.CheClusterSpec{
-			DevWorkspace: orgv1.CheClusterSpecDevWorkspace{
-				Enable: true,
-			},
-		},
-	}
 	cheOperatorDeployment := &appsv1.Deployment{
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      deploy.DefaultCheFlavor(cheCluster) + "-operator",
+			Name:      defaults.GetCheFlavor() + "-operator",
 			Namespace: "eclipse-che",
 		},
 	}
 
-	deployContext := deploy.GetTestDeployContext(cheCluster, []runtime.Object{cheOperatorDeployment})
-
-	util.IsOpenShift = true
-	util.IsOpenShift4 = true
-	err = os.Setenv("ALLOW_DEVWORKSPACE_ENGINE", "true")
-	assert.NoError(t, err)
+	deployContext := test.GetDeployContext(nil, []runtime.Object{cheOperatorDeployment})
+	infrastructure.InitializeForTesting(infrastructure.OpenShiftv4)
 
 	devWorkspaceReconciler := NewDevWorkspaceReconciler()
 	_, done, err := devWorkspaceReconciler.Reconcile(deployContext)
 
-	assert.True(t, done, "Reconcile is not triggered")
+	assert.True(t, done)
 
-	// Get Devworkspace namespace. If error is thrown means devworkspace is not anymore installed if CSV is detected
-	err = deployContext.ClusterAPI.Client.Get(context.TODO(), client.ObjectKey{Name: DevWorkspaceNamespace}, &corev1.Namespace{})
-	assert.True(t, k8sErrors.IsNotFound(err), "DevWorkspace namespace is created when instead DWO CSV is expected to be created")
+	// verify that DWO is not provisioned
+	err = deployContext.ClusterAPI.NonCachingClient.Get(context.TODO(), types.NamespacedName{Name: DevWorkspaceNamespace}, &corev1.Namespace{})
+	assert.True(t, k8sErrors.IsNotFound(err))
 
-	err = os.Unsetenv("NO_OPT_DWO")
-	assert.NoError(t, err)
+	os.Unsetenv("NO_OPT_DWO")
 }
 
 func TestShouldNotReconcileDevWorkspaceIfUnmanagedDWONamespaceExists(t *testing.T) {
-	cheCluster := &orgv1.CheCluster{
-		ObjectMeta: metav1.ObjectMeta{
-			Namespace: "eclipse-che",
-			Name:      "eclipse-che",
-		},
-		Spec: orgv1.CheClusterSpec{
-			DevWorkspace: orgv1.CheClusterSpecDevWorkspace{
-				Enable: true,
-			},
-		},
-	}
 	cheOperatorDeployment := &appsv1.Deployment{
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      deploy.DefaultCheFlavor(cheCluster) + "-operator",
+			Name:      defaults.GetCheFlavor() + "-operator",
 			Namespace: "eclipse-che",
 		},
 	}
@@ -277,14 +199,8 @@ func TestShouldNotReconcileDevWorkspaceIfUnmanagedDWONamespaceExists(t *testing.
 			// no che annotations are there
 		},
 	}
-	deployContext := deploy.GetTestDeployContext(cheCluster, []runtime.Object{cheOperatorDeployment})
-	err := deployContext.ClusterAPI.Client.Create(context.TODO(), dwoNamespace)
-	assert.NoError(t, err)
-
-	util.IsOpenShift = true
-	util.IsOpenShift4 = true
-	err = os.Setenv("ALLOW_DEVWORKSPACE_ENGINE", "true")
-	assert.NoError(t, err)
+	deployContext := test.GetDeployContext(nil, []runtime.Object{cheOperatorDeployment, dwoNamespace})
+	infrastructure.InitializeForTesting(infrastructure.OpenShiftv4)
 
 	devWorkspaceReconciler := NewDevWorkspaceReconciler()
 	_, done, err := devWorkspaceReconciler.Reconcile(deployContext)
@@ -297,20 +213,9 @@ func TestShouldNotReconcileDevWorkspaceIfUnmanagedDWONamespaceExists(t *testing.
 }
 
 func TestReconcileDevWorkspaceIfManagedDWONamespaceExists(t *testing.T) {
-	cheCluster := &orgv1.CheCluster{
-		ObjectMeta: metav1.ObjectMeta{
-			Namespace: "eclipse-che",
-			Name:      "eclipse-che",
-		},
-		Spec: orgv1.CheClusterSpec{
-			DevWorkspace: orgv1.CheClusterSpecDevWorkspace{
-				Enable: true,
-			},
-		},
-	}
 	cheOperatorDeployment := &appsv1.Deployment{
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      deploy.DefaultCheFlavor(cheCluster) + "-operator",
+			Name:      defaults.GetCheFlavor() + "-operator",
 			Namespace: "eclipse-che",
 		},
 	}
@@ -318,24 +223,13 @@ func TestReconcileDevWorkspaceIfManagedDWONamespaceExists(t *testing.T) {
 		ObjectMeta: metav1.ObjectMeta{
 			Name: DevWorkspaceNamespace,
 			Annotations: map[string]string{
-				deploy.CheEclipseOrgNamespace: "eclipse-che",
+				constants.CheEclipseOrgNamespace: "eclipse-che",
 			},
 			// no che annotations are there
 		},
 	}
-
-	deployContext := deploy.GetTestDeployContext(cheCluster, []runtime.Object{cheOperatorDeployment})
-	err := deployContext.ClusterAPI.NonCachingClient.Create(context.TODO(), dwoNamespace)
-	assert.NoError(t, err)
-
-	exists, err := deploy.Get(deployContext,
-		types.NamespacedName{Name: DevWorkspaceNamespace, Namespace: DevWorkspaceNamespace},
-		&corev1.Namespace{})
-
-	util.IsOpenShift = true
-	util.IsOpenShift4 = true
-	err = os.Setenv("ALLOW_DEVWORKSPACE_ENGINE", "true")
-	assert.NoError(t, err)
+	deployContext := test.GetDeployContext(nil, []runtime.Object{cheOperatorDeployment, dwoNamespace})
+	infrastructure.InitializeForTesting(infrastructure.OpenShiftv4)
 
 	devWorkspaceReconciler := NewDevWorkspaceReconciler()
 	_, done, err := devWorkspaceReconciler.Reconcile(deployContext)
@@ -344,7 +238,7 @@ func TestReconcileDevWorkspaceIfManagedDWONamespaceExists(t *testing.T) {
 	assert.NoError(t, err, "Reconcile failed")
 
 	// check is reconcile created deployment if existing namespace is not annotated in che specific way
-	exists, err = deploy.Get(deployContext,
+	exists, err := deploy.Get(deployContext,
 		types.NamespacedName{Name: DevWorkspaceDeploymentName, Namespace: DevWorkspaceNamespace},
 		&appsv1.Deployment{})
 	assert.True(t, exists, "DevWorkspace deployment is not created in Che managed DWO namespace")
