@@ -22,12 +22,17 @@ import (
 
 	"sigs.k8s.io/yaml"
 
+	"github.com/devfile/devworkspace-operator/pkg/infrastructure"
 	"github.com/sirupsen/logrus"
 
+	"github.com/eclipse-che/che-operator/pkg/common/chetypes"
+	"github.com/eclipse-che/che-operator/pkg/common/constants"
+	defaults "github.com/eclipse-che/che-operator/pkg/common/operator-defaults"
+	"github.com/eclipse-che/che-operator/pkg/common/test"
+	"github.com/eclipse-che/che-operator/pkg/common/utils"
 	"github.com/eclipse-che/che-operator/pkg/deploy"
 
-	orgv1 "github.com/eclipse-che/che-operator/api/v1"
-	"github.com/eclipse-che/che-operator/pkg/util"
+	chev2 "github.com/eclipse-che/che-operator/api/v2"
 	"github.com/google/go-cmp/cmp/cmpopts"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
@@ -70,7 +75,7 @@ func NewGatewayReconciler() *GatewayReconciler {
 	return &GatewayReconciler{}
 }
 
-func (p *GatewayReconciler) Reconcile(ctx *deploy.DeployContext) (reconcile.Result, bool, error) {
+func (p *GatewayReconciler) Reconcile(ctx *chetypes.DeployContext) (reconcile.Result, bool, error) {
 	err := SyncGatewayToCluster(ctx)
 	if err != nil {
 		return reconcile.Result{}, false, err
@@ -79,16 +84,16 @@ func (p *GatewayReconciler) Reconcile(ctx *deploy.DeployContext) (reconcile.Resu
 	return reconcile.Result{}, true, nil
 }
 
-func (p *GatewayReconciler) Finalize(ctx *deploy.DeployContext) bool {
+func (p *GatewayReconciler) Finalize(ctx *chetypes.DeployContext) bool {
 	return true
 }
 
 // SyncGatewayToCluster installs or deletes the gateway based on the custom resource configuration
-func SyncGatewayToCluster(deployContext *deploy.DeployContext) error {
+func SyncGatewayToCluster(deployContext *chetypes.DeployContext) error {
 	return syncAll(deployContext)
 }
 
-func syncAll(deployContext *deploy.DeployContext) error {
+func syncAll(deployContext *chetypes.DeployContext) error {
 	instance := deployContext.CheCluster
 	sa := getGatewayServiceAccountSpec(instance)
 	if _, err := deploy.Sync(deployContext, &sa, serviceAccountDiffOpts); err != nil {
@@ -122,7 +127,7 @@ func syncAll(deployContext *deploy.DeployContext) error {
 		return err
 	}
 
-	if util.IsOpenShift {
+	if instance.IsAccessTokenConfigured() {
 		if headerRewritePluginConfig, err := getGatewayHeaderRewritePluginConfigSpec(instance); err == nil {
 			if _, err := deploy.Sync(deployContext, headerRewritePluginConfig, configMapDiffOpts); err != nil {
 				return err
@@ -165,7 +170,7 @@ func syncAll(deployContext *deploy.DeployContext) error {
 	return nil
 }
 
-func getGatewaySecretSpec(deployContext *deploy.DeployContext) (*corev1.Secret, error) {
+func getGatewaySecretSpec(deployContext *chetypes.DeployContext) (*corev1.Secret, error) {
 	secret := &corev1.Secret{}
 	exists, err := deploy.GetNamespacedObject(deployContext, gatewayOauthSecretName, secret)
 	if err == nil && exists {
@@ -181,7 +186,7 @@ func getGatewaySecretSpec(deployContext *deploy.DeployContext) (*corev1.Secret,
 	}
 }
 
-func generateOauthSecretSpec(deployContext *deploy.DeployContext) *corev1.Secret {
+func generateOauthSecretSpec(deployContext *chetypes.DeployContext) *corev1.Secret {
 	return &corev1.Secret{
 		TypeMeta: metav1.TypeMeta{
 			APIVersion: corev1.SchemeGroupVersion.String(),
@@ -190,7 +195,7 @@ func generateOauthSecretSpec(deployContext *deploy.DeployContext) *corev1.Secret
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      gatewayOauthSecretName,
 			Namespace: deployContext.CheCluster.Namespace,
-			Labels:    deploy.GetLabels(deployContext.CheCluster, GatewayServiceName),
+			Labels:    deploy.GetLabels(GatewayServiceName),
 		},
 		Data: map[string][]byte{
 			"cookie_secret": generateRandomCookieSecret(),
@@ -198,7 +203,7 @@ func generateOauthSecretSpec(deployContext *deploy.DeployContext) *corev1.Secret
 	}
 }
 
-func delete(clusterAPI deploy.ClusterAPI, obj metav1.Object) error {
+func delete(clusterAPI chetypes.ClusterAPI, obj metav1.Object) error {
 	key := client.ObjectKey{Name: obj.GetName(), Namespace: obj.GetNamespace()}
 	ro := obj.(client.Object)
 	if getErr := clusterAPI.Client.Get(context.TODO(), key, ro); getErr == nil {
@@ -212,7 +217,7 @@ func delete(clusterAPI deploy.ClusterAPI, obj metav1.Object) error {
 	return nil
 }
 
-func DeleteGatewayRouteConfig(componentName string, deployContext *deploy.DeployContext) error {
+func DeleteGatewayRouteConfig(componentName string, deployContext *chetypes.DeployContext) error {
 	obj := &corev1.ConfigMap{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      GatewayConfigMapNamePrefix + componentName,
@@ -225,7 +230,7 @@ func DeleteGatewayRouteConfig(componentName string, deployContext *deploy.Deploy
 
 // below functions declare the desired states of the various objects required for the gateway
 
-func getGatewayServerConfigSpec(deployContext *deploy.DeployContext) (corev1.ConfigMap, error) {
+func getGatewayServerConfigSpec(deployContext *chetypes.DeployContext) (corev1.ConfigMap, error) {
 	cfg := CreateCommonTraefikConfig(
 		serverComponentName,
 		"PathPrefix(`/api`, `/swagger`, `/_app`)",
@@ -233,21 +238,21 @@ func getGatewayServerConfigSpec(deployContext *deploy.DeployContext) (corev1.Con
 		"http://"+deploy.CheServiceName+":8080",
 		[]string{})
 
-	if util.IsOpenShift {
+	if deployContext.CheCluster.IsAccessTokenConfigured() {
 		cfg.AddAuthHeaderRewrite(serverComponentName)
+	}
+	if infrastructure.IsOpenShift() {
 		// native user mode is currently only available on OpenShift but let's be defensive here so that
 		// this doesn't break once we enable it on Kubernetes, too. Token check will have to work
 		// differently on Kuberentes.
-		if util.IsOpenShift {
-			cfg.AddOpenShiftTokenCheck(serverComponentName)
-		}
+		cfg.AddOpenShiftTokenCheck(serverComponentName)
 	}
 
 	return GetConfigmapForGatewayConfig(deployContext, serverComponentName, cfg)
 }
 
 func GetConfigmapForGatewayConfig(
-	deployContext *deploy.DeployContext,
+	deployContext *chetypes.DeployContext,
 	componentName string,
 	gatewayConfig *TraefikConfig) (corev1.ConfigMap, error) {
 
@@ -264,9 +269,9 @@ func GetConfigmapForGatewayConfig(
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      GatewayConfigMapNamePrefix + componentName,
 			Namespace: deployContext.CheCluster.Namespace,
-			Labels: util.MergeMaps(
-				deploy.GetLabels(deployContext.CheCluster, gatewayConfigComponentName),
-				util.GetMapValue(deployContext.CheCluster.Spec.Server.SingleHostGatewayConfigMapLabels, deploy.DefaultSingleHostGatewayConfigMapLabels)),
+			Labels: labels.Merge(
+				deploy.GetLabels(gatewayConfigComponentName),
+				utils.GetMap(deployContext.CheCluster.Spec.Networking.Auth.Gateway.ConfigLabels, constants.DefaultSingleHostGatewayConfigMapLabels)),
 		},
 		Data: map[string]string{
 			componentName + ".yml": string(gatewayConfigContent),
@@ -278,7 +283,7 @@ func GetConfigmapForGatewayConfig(
 	return ret, nil
 }
 
-func getGatewayServiceAccountSpec(instance *orgv1.CheCluster) corev1.ServiceAccount {
+func getGatewayServiceAccountSpec(instance *chev2.CheCluster) corev1.ServiceAccount {
 	return corev1.ServiceAccount{
 		TypeMeta: metav1.TypeMeta{
 			APIVersion: corev1.SchemeGroupVersion.String(),
@@ -287,12 +292,12 @@ func getGatewayServiceAccountSpec(instance *orgv1.CheCluster) corev1.ServiceAcco
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      GatewayServiceName,
 			Namespace: instance.Namespace,
-			Labels:    deploy.GetLabels(instance, GatewayServiceName),
+			Labels:    deploy.GetLabels(GatewayServiceName),
 		},
 	}
 }
 
-func getGatewayRoleSpec(instance *orgv1.CheCluster) rbac.Role {
+func getGatewayRoleSpec(instance *chev2.CheCluster) rbac.Role {
 	return rbac.Role{
 		TypeMeta: metav1.TypeMeta{
 			APIVersion: rbac.SchemeGroupVersion.String(),
@@ -301,7 +306,7 @@ func getGatewayRoleSpec(instance *orgv1.CheCluster) rbac.Role {
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      GatewayServiceName,
 			Namespace: instance.Namespace,
-			Labels:    deploy.GetLabels(instance, GatewayServiceName),
+			Labels:    deploy.GetLabels(GatewayServiceName),
 		},
 		Rules: []rbac.PolicyRule{
 			{
@@ -313,7 +318,7 @@ func getGatewayRoleSpec(instance *orgv1.CheCluster) rbac.Role {
 	}
 }
 
-func getGatewayRoleBindingSpec(instance *orgv1.CheCluster) rbac.RoleBinding {
+func getGatewayRoleBindingSpec(instance *chev2.CheCluster) rbac.RoleBinding {
 	return rbac.RoleBinding{
 		TypeMeta: metav1.TypeMeta{
 			APIVersion: rbac.SchemeGroupVersion.String(),
@@ -322,7 +327,7 @@ func getGatewayRoleBindingSpec(instance *orgv1.CheCluster) rbac.RoleBinding {
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      GatewayServiceName,
 			Namespace: instance.Namespace,
-			Labels:    deploy.GetLabels(instance, GatewayServiceName),
+			Labels:    deploy.GetLabels(GatewayServiceName),
 		},
 		RoleRef: rbac.RoleRef{
 			APIGroup: "rbac.authorization.k8s.io",
@@ -339,19 +344,19 @@ func getGatewayRoleBindingSpec(instance *orgv1.CheCluster) rbac.RoleBinding {
 }
 
 func generateRandomCookieSecret() []byte {
-	return []byte(base64.StdEncoding.EncodeToString([]byte(util.GeneratePasswd(16))))
+	return []byte(base64.StdEncoding.EncodeToString([]byte(utils.GeneratePassword(16))))
 }
 
-func getGatewayHeaderRewritePluginConfigSpec(instance *orgv1.CheCluster) (*corev1.ConfigMap, error) {
+func getGatewayHeaderRewritePluginConfigSpec(instance *chev2.CheCluster) (*corev1.ConfigMap, error) {
 	headerRewrite, err := ioutil.ReadFile("/tmp/header-rewrite-traefik-plugin/headerRewrite.go")
 	if err != nil {
-		if !util.IsTestMode() {
+		if !test.IsTestMode() {
 			return nil, err
 		}
 	}
 	pluginMeta, err := ioutil.ReadFile("/tmp/header-rewrite-traefik-plugin/.traefik.yml")
 	if err != nil {
-		if !util.IsTestMode() {
+		if !test.IsTestMode() {
 			return nil, err
 		}
 	}
@@ -364,7 +369,7 @@ func getGatewayHeaderRewritePluginConfigSpec(instance *orgv1.CheCluster) (*corev
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      "che-gateway-config-header-rewrite-traefik-plugin",
 			Namespace: instance.Namespace,
-			Labels:    deploy.GetLabels(instance, GatewayServiceName),
+			Labels:    deploy.GetLabels(GatewayServiceName),
 		},
 		Data: map[string]string{
 			"headerRewrite.go": string(headerRewrite),
@@ -373,7 +378,7 @@ func getGatewayHeaderRewritePluginConfigSpec(instance *orgv1.CheCluster) (*corev
 	}, nil
 }
 
-func getGatewayTraefikConfigSpec(instance *orgv1.CheCluster) corev1.ConfigMap {
+func getGatewayTraefikConfigSpec(instance *chev2.CheCluster) corev1.ConfigMap {
 	traefikPort := 8081
 	data := fmt.Sprintf(`
 entrypoints:
@@ -395,7 +400,7 @@ providers:
 log:
   level: "INFO"`, traefikPort)
 
-	if util.IsOpenShift {
+	if instance.IsAccessTokenConfigured() {
 		data += `
 experimental:
   localPlugins:
@@ -411,7 +416,7 @@ experimental:
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      "che-gateway-config",
 			Namespace: instance.Namespace,
-			Labels:    deploy.GetLabels(instance, GatewayServiceName),
+			Labels:    deploy.GetLabels(GatewayServiceName),
 		},
 		Data: map[string]string{
 			"traefik.yml": data,
@@ -419,12 +424,12 @@ experimental:
 	}
 }
 
-func getGatewayDeploymentSpec(ctx *deploy.DeployContext) appsv1.Deployment {
+func getGatewayDeploymentSpec(ctx *chetypes.DeployContext) appsv1.Deployment {
 	terminationGracePeriodSeconds := int64(10)
 
-	deployLabels, labelsSelector := deploy.GetLabelsAndSelector(ctx.CheCluster, GatewayServiceName)
+	deployLabels, labelsSelector := deploy.GetLabelsAndSelector(GatewayServiceName)
 
-	return appsv1.Deployment{
+	deployment := appsv1.Deployment{
 		TypeMeta: metav1.TypeMeta{
 			APIVersion: appsv1.SchemeGroupVersion.String(),
 			Kind:       "Deployment",
@@ -455,19 +460,22 @@ func getGatewayDeploymentSpec(ctx *deploy.DeployContext) appsv1.Deployment {
 			},
 		},
 	}
+
+	deploy.CustomizeDeployment(&deployment, ctx.CheCluster.Spec.Networking.Auth.Gateway.Deployment, false)
+	return deployment
 }
 
-func getContainersSpec(ctx *deploy.DeployContext) []corev1.Container {
-	configLabelsMap := util.GetMapValue(ctx.CheCluster.Spec.Server.SingleHostGatewayConfigMapLabels, deploy.DefaultSingleHostGatewayConfigMapLabels)
-	gatewayImage := util.GetValue(ctx.CheCluster.Spec.Server.SingleHostGatewayImage, deploy.DefaultSingleHostGatewayImage(ctx.CheCluster))
-	configSidecarImage := util.GetValue(ctx.CheCluster.Spec.Server.SingleHostGatewayConfigSidecarImage, deploy.DefaultSingleHostGatewayConfigSidecarImage(ctx.CheCluster))
+func getContainersSpec(ctx *chetypes.DeployContext) []corev1.Container {
+	configLabelsMap := utils.GetMap(ctx.CheCluster.Spec.Networking.Auth.Gateway.ConfigLabels, constants.DefaultSingleHostGatewayConfigMapLabels)
+	gatewayImage := defaults.GetGatewayImage(ctx.CheCluster)
+	configSidecarImage := defaults.GetGatewayConfigSidecarImage(ctx.CheCluster)
 	configLabels := labels.FormatLabels(configLabelsMap)
 
 	containers := []corev1.Container{
 		{
 			Name:            "gateway",
 			Image:           gatewayImage,
-			ImagePullPolicy: corev1.PullAlways,
+			ImagePullPolicy: corev1.PullIfNotPresent,
 			VolumeMounts:    getTraefikContainerVolumeMounts(ctx.CheCluster),
 			Resources: corev1.ResourceRequirements{
 				Limits: corev1.ResourceList{
@@ -483,7 +491,7 @@ func getContainersSpec(ctx *deploy.DeployContext) []corev1.Container {
 		{
 			Name:            "configbump",
 			Image:           configSidecarImage,
-			ImagePullPolicy: corev1.PullAlways,
+			ImagePullPolicy: corev1.PullIfNotPresent,
 			Resources: corev1.ResourceRequirements{
 				Limits: corev1.ResourceList{
 					corev1.ResourceMemory: resource.MustParse("256Mi"),
@@ -529,7 +537,7 @@ func getContainersSpec(ctx *deploy.DeployContext) []corev1.Container {
 	return containers
 }
 
-func getTraefikContainerVolumeMounts(instance *orgv1.CheCluster) []corev1.VolumeMount {
+func getTraefikContainerVolumeMounts(instance *chev2.CheCluster) []corev1.VolumeMount {
 	mounts := []corev1.VolumeMount{
 		{
 			Name:      "static-config",
@@ -540,7 +548,7 @@ func getTraefikContainerVolumeMounts(instance *orgv1.CheCluster) []corev1.Volume
 			MountPath: "/dynamic-config",
 		},
 	}
-	if util.IsOpenShift {
+	if instance.IsAccessTokenConfigured() {
 		mounts = append(mounts, corev1.VolumeMount{
 			Name:      "header-rewrite-traefik-plugin",
 			MountPath: "/plugins-local/src/github.com/che-incubator/header-rewrite-traefik-plugin",
@@ -550,7 +558,7 @@ func getTraefikContainerVolumeMounts(instance *orgv1.CheCluster) []corev1.Volume
 	return mounts
 }
 
-func getVolumesSpec(instance *orgv1.CheCluster) []corev1.Volume {
+func getVolumesSpec(instance *chev2.CheCluster) []corev1.Volume {
 	volumes := []corev1.Volume{
 		{
 			Name: "static-config",
@@ -574,7 +582,7 @@ func getVolumesSpec(instance *orgv1.CheCluster) []corev1.Volume {
 		getOauthProxyConfigVolume(),
 		getKubeRbacProxyConfigVolume())
 
-	if util.IsOpenShift {
+	if instance.IsAccessTokenConfigured() {
 		volumes = append(volumes, corev1.Volume{
 			Name: "header-rewrite-traefik-plugin",
 			VolumeSource: corev1.VolumeSource{
@@ -590,7 +598,7 @@ func getVolumesSpec(instance *orgv1.CheCluster) []corev1.Volume {
 	return volumes
 }
 
-func getGatewayServiceSpec(instance *orgv1.CheCluster) corev1.Service {
+func getGatewayServiceSpec(instance *chev2.CheCluster) corev1.Service {
 	return corev1.Service{
 		TypeMeta: metav1.TypeMeta{
 			APIVersion: corev1.SchemeGroupVersion.String(),
@@ -599,10 +607,10 @@ func getGatewayServiceSpec(instance *orgv1.CheCluster) corev1.Service {
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      GatewayServiceName,
 			Namespace: instance.Namespace,
-			Labels:    deploy.GetLabels(instance, GatewayServiceName),
+			Labels:    deploy.GetLabels(GatewayServiceName),
 		},
 		Spec: corev1.ServiceSpec{
-			Selector:        deploy.GetLabels(instance, GatewayServiceName),
+			Selector:        deploy.GetLabels(GatewayServiceName),
 			SessionAffinity: corev1.ServiceAffinityNone,
 			Type:            corev1.ServiceTypeClusterIP,
 			Ports: []corev1.ServicePort{
