@@ -18,9 +18,12 @@ import (
 	"time"
 
 	chev1alpha1 "github.com/che-incubator/kubernetes-image-puller-operator/api/v1alpha1"
-	orgv1 "github.com/eclipse-che/che-operator/api/v1"
+	chev2 "github.com/eclipse-che/che-operator/api/v2"
+	"github.com/eclipse-che/che-operator/pkg/common/chetypes"
+	"github.com/eclipse-che/che-operator/pkg/common/constants"
+	defaults "github.com/eclipse-che/che-operator/pkg/common/operator-defaults"
+	"github.com/eclipse-che/che-operator/pkg/common/utils"
 	"github.com/eclipse-che/che-operator/pkg/deploy"
-	"github.com/eclipse-che/che-operator/pkg/util"
 	operatorsv1 "github.com/operator-framework/api/pkg/operators/v1"
 	operatorsv1alpha1 "github.com/operator-framework/api/pkg/operators/v1alpha1"
 	packagesv1 "github.com/operator-framework/operator-lifecycle-manager/pkg/package-server/apis/operators/v1"
@@ -54,17 +57,17 @@ func NewImagePuller() *ImagePuller {
 	return &ImagePuller{}
 }
 
-func (ip *ImagePuller) Reconcile(ctx *deploy.DeployContext) (reconcile.Result, bool, error) {
+func (ip *ImagePuller) Reconcile(ctx *chetypes.DeployContext) (reconcile.Result, bool, error) {
 	return ReconcileImagePuller(ctx)
 }
 
-func (ip *ImagePuller) Finalize(ctx *deploy.DeployContext) bool {
+func (ip *ImagePuller) Finalize(ctx *chetypes.DeployContext) bool {
 	return DeleteImagePullerOperatorAndFinalizer(ctx)
 }
 
 // Reconcile the imagePuller section of the CheCluster CR.  If imagePuller.enable is set to true, install the Kubernetes Image Puller operator and create
 // a KubernetesImagePuller CR.  Add a finalizer to the CheCluster CR.  If false, remove the KubernetesImagePuller CR, uninstall the operator, and remove the finalizer.
-func ReconcileImagePuller(ctx *deploy.DeployContext) (reconcile.Result, bool, error) {
+func ReconcileImagePuller(ctx *chetypes.DeployContext) (reconcile.Result, bool, error) {
 	// Determine what server groups the API Server knows about
 	foundPackagesAPI, foundOperatorsAPI, _, err := CheckNeededImagePullerApis(ctx)
 	if err != nil {
@@ -73,12 +76,12 @@ func ReconcileImagePuller(ctx *deploy.DeployContext) (reconcile.Result, bool, er
 	}
 
 	// If the image puller should be installed but the APIServer doesn't know about PackageManifests/Subscriptions, log a warning and requeue
-	if ctx.CheCluster.Spec.ImagePuller.Enable && (!foundPackagesAPI || !foundOperatorsAPI) {
+	if ctx.CheCluster.Spec.Components.ImagePuller.Enable && (!foundPackagesAPI || !foundOperatorsAPI) {
 		logrus.Infof("Couldn't find Operator Lifecycle Manager types to install the Kubernetes Image Puller Operator.  Please install Operator Lifecycle Manager to install the operator or disable the image puller by setting spec.imagePuller.enable to false.")
 		return reconcile.Result{RequeueAfter: time.Second}, false, nil
 	}
 
-	if ctx.CheCluster.Spec.ImagePuller.Enable {
+	if ctx.CheCluster.Spec.Components.ImagePuller.Enable {
 		if foundOperatorsAPI && foundPackagesAPI {
 			packageManifest, err := GetPackageManifest(ctx)
 			if err != nil {
@@ -168,19 +171,19 @@ func ReconcileImagePuller(ctx *deploy.DeployContext) (reconcile.Result, bool, er
 				return reconcile.Result{}, false, err
 			}
 
-			if ctx.CheCluster.Spec.ImagePuller.Spec.DeploymentName == "" {
-				ctx.CheCluster.Spec.ImagePuller.Spec.DeploymentName = imagePuller.Spec.DeploymentName
+			if ctx.CheCluster.Spec.Components.ImagePuller.Spec.DeploymentName == "" {
+				ctx.CheCluster.Spec.Components.ImagePuller.Spec.DeploymentName = imagePuller.Spec.DeploymentName
 			}
-			if ctx.CheCluster.Spec.ImagePuller.Spec.ConfigMapName == "" {
-				ctx.CheCluster.Spec.ImagePuller.Spec.ConfigMapName = imagePuller.Spec.ConfigMapName
+			if ctx.CheCluster.Spec.Components.ImagePuller.Spec.ConfigMapName == "" {
+				ctx.CheCluster.Spec.Components.ImagePuller.Spec.ConfigMapName = imagePuller.Spec.ConfigMapName
 			}
-			if ctx.CheCluster.Spec.ImagePuller.Spec.ImagePullerImage == "" {
-				ctx.CheCluster.Spec.ImagePuller.Spec.ImagePullerImage = imagePuller.Spec.ImagePullerImage
+			if ctx.CheCluster.Spec.Components.ImagePuller.Spec.ImagePullerImage == "" {
+				ctx.CheCluster.Spec.Components.ImagePuller.Spec.ImagePullerImage = imagePuller.Spec.ImagePullerImage
 			}
 
 			// If ImagePuller specs are different, update the KubernetesImagePuller CR
-			if imagePuller.Spec != ctx.CheCluster.Spec.ImagePuller.Spec {
-				imagePuller.Spec = ctx.CheCluster.Spec.ImagePuller.Spec
+			if imagePuller.Spec != ctx.CheCluster.Spec.Components.ImagePuller.Spec {
+				imagePuller.Spec = ctx.CheCluster.Spec.Components.ImagePuller.Spec
 				logrus.Infof("Updating KubernetesImagePuller %v", imagePuller.Name)
 				if err = ctx.ClusterAPI.Client.Update(context.TODO(), imagePuller, &client.UpdateOptions{}); err != nil {
 					logrus.Errorf("Error updating KubernetesImagePuller: %v", err)
@@ -202,7 +205,7 @@ func ReconcileImagePuller(ctx *deploy.DeployContext) (reconcile.Result, bool, er
 	return reconcile.Result{}, true, nil
 }
 
-func DeleteImagePullerOperatorAndFinalizer(ctx *deploy.DeployContext) bool {
+func DeleteImagePullerOperatorAndFinalizer(ctx *chetypes.DeployContext) bool {
 	done := true
 
 	if _, err := GetImagePullerOperator(ctx); err == nil {
@@ -222,7 +225,7 @@ func DeleteImagePullerOperatorAndFinalizer(ctx *deploy.DeployContext) bool {
 	return done
 }
 
-func HasImagePullerFinalizer(instance *orgv1.CheCluster) bool {
+func HasImagePullerFinalizer(instance *chev2.CheCluster) bool {
 	finalizers := instance.ObjectMeta.GetFinalizers()
 	for _, finalizer := range finalizers {
 		if finalizer == imagePullerFinalizerName {
@@ -232,13 +235,13 @@ func HasImagePullerFinalizer(instance *orgv1.CheCluster) bool {
 	return false
 }
 
-func ReconcileImagePullerFinalizer(ctx *deploy.DeployContext) (err error) {
+func ReconcileImagePullerFinalizer(ctx *chetypes.DeployContext) (err error) {
 	instance := ctx.CheCluster
 	if instance.ObjectMeta.DeletionTimestamp.IsZero() {
 		return deploy.AppendFinalizer(ctx, imagePullerFinalizerName)
 	} else {
-		if util.ContainsString(instance.ObjectMeta.Finalizers, imagePullerFinalizerName) {
-			clusterServiceVersionName := deploy.DefaultKubernetesImagePullerOperatorCSV()
+		if utils.Contains(instance.ObjectMeta.Finalizers, imagePullerFinalizerName) {
+			clusterServiceVersionName := constants.KubernetesImagePullerOperatorCSV
 			logrus.Infof("Custom resource %s is being deleted. Deleting ClusterServiceVersion %s first", instance.Name, clusterServiceVersionName)
 			clusterServiceVersion := &operatorsv1alpha1.ClusterServiceVersion{}
 			err := ctx.ClusterAPI.NonCachingClient.Get(context.TODO(), types.NamespacedName{Namespace: instance.Namespace, Name: clusterServiceVersionName}, clusterServiceVersion)
@@ -257,9 +260,9 @@ func ReconcileImagePullerFinalizer(ctx *deploy.DeployContext) (err error) {
 	}
 }
 
-func DeleteImagePullerFinalizer(ctx *deploy.DeployContext) (err error) {
+func DeleteImagePullerFinalizer(ctx *chetypes.DeployContext) (err error) {
 	instance := ctx.CheCluster
-	instance.ObjectMeta.Finalizers = util.DoRemoveString(instance.ObjectMeta.Finalizers, imagePullerFinalizerName)
+	instance.ObjectMeta.Finalizers = utils.Remove(instance.ObjectMeta.Finalizers, imagePullerFinalizerName)
 	logrus.Infof("Removing image puller finalizer on %s CR", instance.Name)
 	if err := ctx.ClusterAPI.Client.Update(context.Background(), instance); err != nil {
 		logrus.Errorf("Failed to update %s CR: %s", instance.Name, err)
@@ -285,7 +288,7 @@ func SubscriptionsAreEqual(expected *operatorsv1alpha1.Subscription, actual *ope
 // foundOperatorsAPI - true if the server discovers the operators.coreos.com API
 // foundKubernetesImagePullerAPI - true if the server discovers the che.eclipse.org API
 // error - any error returned by the call to discoveryClient.ServerGroups()
-func CheckNeededImagePullerApis(ctx *deploy.DeployContext) (bool, bool, bool, error) {
+func CheckNeededImagePullerApis(ctx *chetypes.DeployContext) (bool, bool, bool, error) {
 	groupList, resourcesList, err := ctx.ClusterAPI.DiscoveryClient.ServerGroupsAndResources()
 	if err != nil {
 		return false, false, false, err
@@ -313,7 +316,7 @@ func CheckNeededImagePullerApis(ctx *deploy.DeployContext) (bool, bool, bool, er
 }
 
 // Search for the kubernetes-imagepuller-operator PackageManifest
-func GetPackageManifest(ctx *deploy.DeployContext) (*packagesv1.PackageManifest, error) {
+func GetPackageManifest(ctx *chetypes.DeployContext) (*packagesv1.PackageManifest, error) {
 	packageManifest := &packagesv1.PackageManifest{}
 	err := ctx.ClusterAPI.NonCachingClient.Get(context.TODO(), types.NamespacedName{Namespace: ctx.CheCluster.Namespace, Name: "kubernetes-imagepuller-operator"}, packageManifest)
 	if err != nil {
@@ -324,7 +327,7 @@ func GetPackageManifest(ctx *deploy.DeployContext) (*packagesv1.PackageManifest,
 
 // Create an OperatorGroup in the CheCluster namespace if it does not exist.  Returns true if the
 // OperatorGroup was created, and any error returned during the List and Create operation
-func CreateOperatorGroupIfNotFound(ctx *deploy.DeployContext) (bool, error) {
+func CreateOperatorGroupIfNotFound(ctx *chetypes.DeployContext) (bool, error) {
 	operatorGroupList := &operatorsv1.OperatorGroupList{}
 	err := ctx.ClusterAPI.NonCachingClient.List(context.TODO(), operatorGroupList, &client.ListOptions{Namespace: ctx.CheCluster.Namespace})
 	if err != nil {
@@ -355,7 +358,7 @@ func CreateOperatorGroupIfNotFound(ctx *deploy.DeployContext) (bool, error) {
 	return false, nil
 }
 
-func CreateImagePullerSubscription(ctx *deploy.DeployContext, packageManifest *packagesv1.PackageManifest) (bool, error) {
+func CreateImagePullerSubscription(ctx *chetypes.DeployContext, packageManifest *packagesv1.PackageManifest) (bool, error) {
 	imagePullerOperatorSubscription := &operatorsv1alpha1.Subscription{}
 	err := ctx.ClusterAPI.NonCachingClient.Get(context.TODO(), types.NamespacedName{
 		Name:      "kubernetes-imagepuller-operator",
@@ -375,7 +378,7 @@ func CreateImagePullerSubscription(ctx *deploy.DeployContext, packageManifest *p
 	return false, nil
 }
 
-func GetExpectedSubscription(ctx *deploy.DeployContext, packageManifest *packagesv1.PackageManifest) *operatorsv1alpha1.Subscription {
+func GetExpectedSubscription(ctx *chetypes.DeployContext, packageManifest *packagesv1.PackageManifest) *operatorsv1alpha1.Subscription {
 	return &operatorsv1alpha1.Subscription{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      "kubernetes-imagepuller-operator",
@@ -394,7 +397,7 @@ func GetExpectedSubscription(ctx *deploy.DeployContext, packageManifest *package
 	}
 }
 
-func GetActualSubscription(ctx *deploy.DeployContext) (*operatorsv1alpha1.Subscription, error) {
+func GetActualSubscription(ctx *chetypes.DeployContext) (*operatorsv1alpha1.Subscription, error) {
 	actual := &operatorsv1alpha1.Subscription{}
 	err := ctx.ClusterAPI.NonCachingClient.Get(context.TODO(), types.NamespacedName{Namespace: ctx.CheCluster.Namespace, Name: "kubernetes-imagepuller-operator"}, actual)
 	if err != nil {
@@ -405,21 +408,21 @@ func GetActualSubscription(ctx *deploy.DeployContext) (*operatorsv1alpha1.Subscr
 
 // Update the CheCluster ImagePuller spec if the default values are not set
 // returns the updated spec and an error during update
-func UpdateImagePullerSpecIfEmpty(ctx *deploy.DeployContext) (orgv1.CheClusterSpecImagePuller, error) {
-	if ctx.CheCluster.Spec.ImagePuller.Spec.DeploymentName == "" {
-		ctx.CheCluster.Spec.ImagePuller.Spec.DeploymentName = "kubernetes-image-puller"
+func UpdateImagePullerSpecIfEmpty(ctx *chetypes.DeployContext) (chev2.ImagePuller, error) {
+	if ctx.CheCluster.Spec.Components.ImagePuller.Spec.DeploymentName == "" {
+		ctx.CheCluster.Spec.Components.ImagePuller.Spec.DeploymentName = "kubernetes-image-puller"
 	}
-	if ctx.CheCluster.Spec.ImagePuller.Spec.ConfigMapName == "" {
-		ctx.CheCluster.Spec.ImagePuller.Spec.ConfigMapName = "k8s-image-puller"
+	if ctx.CheCluster.Spec.Components.ImagePuller.Spec.ConfigMapName == "" {
+		ctx.CheCluster.Spec.Components.ImagePuller.Spec.ConfigMapName = "k8s-image-puller"
 	}
 	err := ctx.ClusterAPI.Client.Update(context.TODO(), ctx.CheCluster, &client.UpdateOptions{})
 	if err != nil {
-		return ctx.CheCluster.Spec.ImagePuller, err
+		return ctx.CheCluster.Spec.Components.ImagePuller, err
 	}
-	return ctx.CheCluster.Spec.ImagePuller, nil
+	return ctx.CheCluster.Spec.Components.ImagePuller, nil
 }
 
-func SetDefaultImages(ctx *deploy.DeployContext) error {
+func SetDefaultImages(ctx *chetypes.DeployContext) error {
 	defaultImages := GetDefaultImages()
 	if len(defaultImages) == 0 {
 		return nil
@@ -482,7 +485,7 @@ func GetDefaultImages() []ImageAndName {
 		"^RELATED_IMAGE_.*_java.{1,2}(_maven)?_devfile_registry_image.*",
 	}
 	for _, pattern := range imagePatterns {
-		matches := util.GetEnvByRegExp(pattern)
+		matches := utils.GetEnvByRegExp(pattern)
 		for _, match := range matches {
 			match.Name = match.Name[len("RELATED_IMAGE_"):]
 			images = append(images, ImageAndName{Name: match.Name, Image: match.Value})
@@ -518,7 +521,7 @@ func IsRFC1123Char(ch byte) bool {
 	return len(errs) == 0
 }
 
-func CreateKubernetesImagePuller(ctx *deploy.DeployContext) (bool, error) {
+func CreateKubernetesImagePuller(ctx *chetypes.DeployContext) (bool, error) {
 	imagePuller := GetExpectedKubernetesImagePuller(ctx)
 	err := ctx.ClusterAPI.Client.Create(context.TODO(), imagePuller, &client.CreateOptions{})
 	if err != nil {
@@ -527,7 +530,7 @@ func CreateKubernetesImagePuller(ctx *deploy.DeployContext) (bool, error) {
 	return true, nil
 }
 
-func GetExpectedKubernetesImagePuller(ctx *deploy.DeployContext) *chev1alpha1.KubernetesImagePuller {
+func GetExpectedKubernetesImagePuller(ctx *chetypes.DeployContext) *chev1alpha1.KubernetesImagePuller {
 	return &chev1alpha1.KubernetesImagePuller{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      ctx.CheCluster.Name + "-image-puller",
@@ -536,18 +539,18 @@ func GetExpectedKubernetesImagePuller(ctx *deploy.DeployContext) *chev1alpha1.Ku
 				*metav1.NewControllerRef(ctx.CheCluster, ctx.CheCluster.GroupVersionKind()),
 			},
 			Labels: map[string]string{
-				"app.kubernetes.io/part-of": deploy.CheEclipseOrg,
-				"app":                       deploy.DefaultCheFlavor(ctx.CheCluster),
+				"app.kubernetes.io/part-of": constants.CheEclipseOrg,
+				"app":                       defaults.GetCheFlavor(),
 				"component":                 "kubernetes-image-puller",
 			},
 		},
-		Spec: ctx.CheCluster.Spec.ImagePuller.Spec,
+		Spec: ctx.CheCluster.Spec.Components.ImagePuller.Spec,
 	}
 }
 
 // UpdateDefaultImagesIfNeeded updates the default images from `spec.images` if needed
-func UpdateDefaultImagesIfNeeded(ctx *deploy.DeployContext) error {
-	specImages := StringToImageSlice(ctx.CheCluster.Spec.ImagePuller.Spec.Images)
+func UpdateDefaultImagesIfNeeded(ctx *chetypes.DeployContext) error {
+	specImages := StringToImageSlice(ctx.CheCluster.Spec.Components.ImagePuller.Spec.Images)
 	defaultImages := GetDefaultImages()
 	if UpdateSpecImages(specImages, defaultImages) {
 		return SetImages(ctx, specImages)
@@ -563,9 +566,9 @@ func UpdateDefaultImagesIfNeeded(ctx *deploy.DeployContext) error {
 func UpdateSpecImages(specImages []ImageAndName, defaultImages []ImageAndName) bool {
 	match := false
 	for i, specImage := range specImages {
-		specImageName, specImageTag := util.GetImageNameAndTag(specImage.Image)
+		specImageName, specImageTag := utils.GetImageNameAndTag(specImage.Image)
 		for _, defaultImage := range defaultImages {
-			defaultImageName, defaultImageTag := util.GetImageNameAndTag(defaultImage.Image)
+			defaultImageName, defaultImageTag := utils.GetImageNameAndTag(defaultImage.Image)
 			// if the image tags are different for this image, then update
 			if defaultImageName == specImageName && defaultImageTag != specImageTag {
 				match = true
@@ -578,15 +581,15 @@ func UpdateSpecImages(specImages []ImageAndName, defaultImages []ImageAndName) b
 }
 
 // SetImages sets the provided images to the imagePuller spec
-func SetImages(ctx *deploy.DeployContext, images []ImageAndName) error {
+func SetImages(ctx *chetypes.DeployContext, images []ImageAndName) error {
 	imagesStr := ImageSliceToString(images)
-	ctx.CheCluster.Spec.ImagePuller.Spec.Images = imagesStr
+	ctx.CheCluster.Spec.Components.ImagePuller.Spec.Images = imagesStr
 	return deploy.UpdateCheCRSpec(ctx, "Kubernetes Image Puller images", imagesStr)
 }
 
 // Uninstall the CSV, OperatorGroup, Subscription, KubernetesImagePuller, and update the CheCluster to remove
 // the image puller spec.  Returns true if the CheCluster was updated
-func UninstallImagePullerOperator(ctx *deploy.DeployContext) (bool, error) {
+func UninstallImagePullerOperator(ctx *chetypes.DeployContext) (bool, error) {
 	updated := false
 	_, hasOperatorsAPIs, hasImagePullerAPIs, err := CheckNeededImagePullerApis(ctx)
 	if err != nil {
@@ -610,7 +613,7 @@ func UninstallImagePullerOperator(ctx *deploy.DeployContext) (bool, error) {
 	if hasOperatorsAPIs {
 		// Delete the ClusterServiceVersion
 		csv := &operatorsv1alpha1.ClusterServiceVersion{}
-		err = ctx.ClusterAPI.NonCachingClient.Get(context.TODO(), types.NamespacedName{Namespace: ctx.CheCluster.Namespace, Name: deploy.DefaultKubernetesImagePullerOperatorCSV()}, csv)
+		err = ctx.ClusterAPI.NonCachingClient.Get(context.TODO(), types.NamespacedName{Namespace: ctx.CheCluster.Namespace, Name: constants.KubernetesImagePullerOperatorCSV}, csv)
 		if err != nil && !errors.IsNotFound(err) {
 			return updated, err
 		}
@@ -654,9 +657,9 @@ func UninstallImagePullerOperator(ctx *deploy.DeployContext) (bool, error) {
 	}
 
 	// Update CR to remove imagePullerSpec
-	if (ctx.CheCluster.Spec.ImagePuller.Enable || ctx.CheCluster.Spec.ImagePuller.Spec != (chev1alpha1.KubernetesImagePullerSpec{})) &&
+	if (ctx.CheCluster.Spec.Components.ImagePuller.Enable || ctx.CheCluster.Spec.Components.ImagePuller.Spec != (chev1alpha1.KubernetesImagePullerSpec{})) &&
 		ctx.CheCluster.ObjectMeta.DeletionTimestamp.IsZero() {
-		ctx.CheCluster.Spec.ImagePuller.Spec = chev1alpha1.KubernetesImagePullerSpec{}
+		ctx.CheCluster.Spec.Components.ImagePuller.Spec = chev1alpha1.KubernetesImagePullerSpec{}
 		logrus.Infof("Updating CheCluster %v to remove image puller spec", ctx.CheCluster.Name)
 		err := ctx.ClusterAPI.Client.Update(context.TODO(), ctx.CheCluster, &client.UpdateOptions{})
 		if err != nil {
@@ -668,7 +671,7 @@ func UninstallImagePullerOperator(ctx *deploy.DeployContext) (bool, error) {
 }
 
 // GetImagePullerOperator returns the current kubernetes-imagepuller-operator if exists
-func GetImagePullerOperator(ctx *deploy.DeployContext) (*chev1alpha1.KubernetesImagePuller, error) {
+func GetImagePullerOperator(ctx *chetypes.DeployContext) (*chev1alpha1.KubernetesImagePuller, error) {
 	imagePuller := &chev1alpha1.KubernetesImagePuller{}
 	err := ctx.ClusterAPI.Client.Get(context.TODO(), types.NamespacedName{Namespace: ctx.CheCluster.Namespace, Name: ctx.CheCluster.Name + "-image-puller"}, imagePuller)
 	if err != nil {
